==> instabug-apm-14.2.0-sources.jar: com/instabug/apm/compose/compose_spans/ComposeSpansEventListener.kt <==
package com.instabug.apm.compose.compose_spans

import com.instabug.apm.compose.ComposeEventListener
import com.instabug.apm.compose.compose_spans.model.ComposeSpanEvent
import com.instabug.apm.compose.compose_spans.model.ComposeSpanEventId
import com.instabug.apm.model.EventTimeMetricCapture

class ComposeSpansEventListener(
    private val repository: ComposeSpansEventsRepository
): ComposeEventListener {

    override fun onCompositionStarted(
        id: Int,
        screenName: String,
        timeMetricCapture: EventTimeMetricCapture
    ) {
        repository.addEvent(
            ComposeSpanEvent(
                id,
                screenName,
                ComposeSpanEventId.CompositionStarted,
                timeMetricCapture
            )
        )
    }

    override fun onCompositionEnded(
        id: Int,
        screenName: String,
        timeMetricCapture: EventTimeMetricCapture
    ) {
        repository.addEvent(
            ComposeSpanEvent(
                id,
                screenName,
                ComposeSpanEventId.CompositionEnded,
                timeMetricCapture
            )
        )
    }

    override fun onMeasuringAndLayoutStarted(
        id: Int,
        screenName: String,
        timeMetricCapture: EventTimeMetricCapture
    ) {
        repository.addEvent(
            ComposeSpanEvent(
                id,
                screenName,
                ComposeSpanEventId.MeasuringAndLayoutStarted,
                timeMetricCapture
            )
        )
    }

    override fun onMeasuringAndLayoutEnded(
        id: Int,
        screenName: String,
        timeMetricCapture: EventTimeMetricCapture
    ) {
        repository.addEvent(
            ComposeSpanEvent(
                id,
                screenName,
                ComposeSpanEventId.MeasuringAndLayoutEnded,
                timeMetricCapture
            )
        )
    }

    override fun onRenderingStarted(
        id: Int,
        screenName: String,
        timeMetricCapture: EventTimeMetricCapture
    ) {
        repository.addEvent(
            ComposeSpanEvent(
                id,
                screenName,
                ComposeSpanEventId.RenderingStarted,
                timeMetricCapture
            )
        )
    }

    override fun onRenderingEnded(
        id: Int,
        screenName: String,
        timeMetricCapture: EventTimeMetricCapture
    ) {
        repository.addEvent(
            ComposeSpanEvent(
                id,
                screenName,
                ComposeSpanEventId.RenderingEnded,
                timeMetricCapture
            )
        )
    }

    override fun onDispose(
        id: Int,
        screenName: String,
        timeMetricCapture: EventTimeMetricCapture
    ) {
        repository.addEvent(
            ComposeSpanEvent(
                id,
                screenName,
                ComposeSpanEventId.Dispose,
                timeMetricCapture
            )
        )
    }
}

==> instabug-apm-16.0.0-sources.jar: com/instabug/apm/compose/compose_spans/ComposeSpansEventListener.kt <==
package com.instabug.apm.compose.compose_spans

import com.instabug.apm.compose.ComposeEventListener
import com.instabug.apm.compose.compose_spans.model.ComposeSpanEvent
import com.instabug.apm.model.EventTimeMetricCapture

class ComposeSpansEventListener(
    private val repository: ComposeSpansEventsRepository
) : ComposeEventListener {

    override fun onCompositionStarted(
        id: Int,
        screenName: String,
        timeMetricCapture: EventTimeMetricCapture,
        showAsScreen: Boolean
    ) {
        repository.addEvent(
            ComposeSpanEvent.CompositionStarted(
                id,
                screenName,
                timeMetricCapture,
                showAsScreen
            )
        )
    }

    override fun onCompositionEnded(
        id: Int,
        screenName: String,
        timeMetricCapture: EventTimeMetricCapture
    ) {
        repository.addEvent(
            ComposeSpanEvent.CompositionEnded(
                id,
                screenName,
                timeMetricCapture
            )
        )
    }

    override fun onMeasuringAndLayoutStarted(
        id: Int,
        screenName: String,
        timeMetricCapture: EventTimeMetricCapture
    ) {
        repository.addEvent(
            ComposeSpanEvent.MeasuringAndLayoutStarted(
                id,
                screenName,
                timeMetricCapture
            )
        )
    }

    override fun onMeasuringAndLayoutEnded(
        id: Int,
        screenName: String,
        timeMetricCapture: EventTimeMetricCapture
    ) {
        repository.addEvent(
            ComposeSpanEvent.MeasuringAndLayoutEnded(
                id,
                screenName,
                timeMetricCapture
            )
        )
    }

    override fun onRenderingStarted(
        id: Int,
        screenName: String,
        timeMetricCapture: EventTimeMetricCapture
    ) {
        repository.addEvent(
            ComposeSpanEvent.RenderingStarted(
                id,
                screenName,
                timeMetricCapture
            )
        )
    }

    override fun onRenderingEnded(
        id: Int,
        screenName: String,
        timeMetricCapture: EventTimeMetricCapture
    ) {
        repository.addEvent(
            ComposeSpanEvent.RenderingEnded(
                id,
                screenName,
                timeMetricCapture
            )
        )
    }

    override fun onDispose(
        id: Int,
        screenName: String,
        timeMetricCapture: EventTimeMetricCapture
    ) {
        repository.addEvent(
            ComposeSpanEvent.Dispose(
                id,
                screenName,
                timeMetricCapture
            )
        )
    }
}
